@@ -28,8 +28,8 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker/helperimage"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
@@ -260,7 +260,7 @@ func (e *executor) loadPrebuiltImage(path, ref, tag string) (*types.ImageInspect
 			return nil, err
 		}
 
-		return nil, fmt.Errorf("Cannot load prebuilt image: %s: %q", path, err.Error())
+		return nil, fmt.Errorf("Cannot load prebuilt image: %s: %w", path, err)
 	}
 	defer file.Close()
 
@@ -273,7 +273,7 @@ func (e *executor) loadPrebuiltImage(path, ref, tag string) (*types.ImageInspect
 	options := types.ImageImportOptions{Tag: tag}
 
 	if err := e.client.ImageImportBlocking(e.Context, source, ref, options); err != nil {
-		return nil, fmt.Errorf("Failed to import image: %s", err)
+		return nil, fmt.Errorf("Failed to import image: %w", err)
 	}
 
 	image, _, err := e.client.ImageInspectWithRaw(e.Context, ref+":"+tag)
@@ -404,7 +404,7 @@ func (e *executor) bindDevices() (err error) {
 	for _, deviceString := range e.Config.Docker.Devices {
 		device, err := e.parseDeviceString(deviceString)
 		if err != nil {
-			err = fmt.Errorf("Failed to parse device string %q: %s", deviceString, err)
+			err = fmt.Errorf("Failed to parse device string %q: %w", deviceString, err)
 			return err
 		}
 
@@ -531,14 +531,17 @@ func (e *executor) createService(serviceIndex int, service, version, image strin
 }
 
 func (e *executor) getServicesDefinitions() (common.Services, error) {
+	internalServiceImages := []string{}
 	serviceDefinitions := common.Services{}
+
 	for _, service := range e.Config.Docker.Services {
-		serviceDefinitions = append(serviceDefinitions, common.Image{Name: service})
+		internalServiceImages = append(internalServiceImages, service.Name)
+		serviceDefinitions = append(serviceDefinitions, service.ToImageDefinition())
 	}
 
 	for _, service := range e.Build.Services {
 		serviceName := e.Build.GetAllVariables().ExpandValue(service.Name)
-		err := e.verifyAllowedImage(serviceName, "services", e.Config.Docker.AllowedServices, e.Config.Docker.Services)
+		err := e.verifyAllowedImage(serviceName, "services", e.Config.Docker.AllowedServices, internalServiceImages)
 		if err != nil {
 			return nil, err
 		}
@@ -1227,7 +1230,7 @@ func (e *serviceHealthCheckError) Error() string {
 func (e *executor) runServiceHealthCheckContainer(service *types.Container, timeout time.Duration) error {
 	waitImage, err := e.getPrebuiltImage()
 	if err != nil {
-		return fmt.Errorf("getPrebuiltImage: %v", err)
+		return fmt.Errorf("getPrebuiltImage: %w", err)
 	}
 
 	containerName := service.Names[0] + "-wait-for-service"
@@ -1250,12 +1253,12 @@ func (e *executor) runServiceHealthCheckContainer(service *types.Container, time
 	e.Debugln("Waiting for service container", containerName, "to be up and running...")
 	resp, err := e.client.ContainerCreate(e.Context, config, hostConfig, nil, containerName)
 	if err != nil {
-		return fmt.Errorf("ContainerCreate: %v", err)
+		return fmt.Errorf("ContainerCreate: %w", err)
 	}
 	defer e.removeContainer(e.Context, resp.ID)
 	err = e.client.ContainerStart(e.Context, resp.ID, types.ContainerStartOptions{})
 	if err != nil {
-		return fmt.Errorf("ContainerStart: %v", err)
+		return fmt.Errorf("ContainerStart: %w", err)
 	}
 
 	waitResult := make(chan error, 1)
