@@ -30,12 +30,12 @@ func newChainResolver(urlResolver resolver, verifyResolver resolver) resolver {
 func (r *chainResolver) Resolve(certs []*x509.Certificate) ([]*x509.Certificate, error) {
 	certs, err := r.urlResolver.Resolve(certs)
 	if err != nil {
-		return nil, fmt.Errorf("error while resolving certificates chain with URL: %v", err)
+		return nil, fmt.Errorf("error while resolving certificates chain with URL: %w", err)
 	}
 
 	certs, err = r.verifyResolver.Resolve(certs)
 	if err != nil {
-		return nil, fmt.Errorf("error while resolving certificates chain with verification: %v", err)
+		return nil, fmt.Errorf("error while resolving certificates chain with verification: %w", err)
 	}
 
 	return certs, err
